FixedArray

Trait FixedArray 

pub unsafe trait FixedArray:
    Arg
    + 'static
    + Clone
    + Copy { }
If a type implements this trait, it means the size and alignment is the same as in D-Bus. This means that you can quickly append and get slices of this type.

Note: Booleans do not implement this trait because D-Bus booleans are 4 bytes and Rust booleans are 1 byte.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl FixedArray for f64

Source

impl FixedArray for i16

Source

impl FixedArray for i32

Source

impl FixedArray for i64

Source

impl FixedArray for u8

Source

impl FixedArray for u16

Source

impl FixedArray for u32

Source

impl FixedArray for u64

Implementors