pub trait ReadAll: Sized {
// Required method
fn read(i: &mut Iter<'_>) -> Result<Self, TypeMismatchError>;
}Expand description
Helper trait to read all arguments from a message.
Required Methods
Sourcefn read(i: &mut Iter<'_>) -> Result<Self, TypeMismatchError>
fn read(i: &mut Iter<'_>) -> Result<Self, TypeMismatchError>
Performs the read operation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl ReadAll for VecDeque<Box<dyn RefArg>>
This is a fallback for methods that have tons of arguments.
Usually we’ll use a tuple because it is more ergonomic, but ReadAll is only
implemented for tuples up to a certain size.
impl ReadAll for VecDeque<Box<dyn RefArg>>
This is a fallback for methods that have tons of arguments. Usually we’ll use a tuple because it is more ergonomic, but ReadAll is only implemented for tuples up to a certain size.